itkwasm-htj2k
=======

> Wasm-SIMD accelerated decoding and encoding High-throughput JPEG2000 (HTJ2K) images.

[![itkwasm-htj2k version](https://badge.fury.io/py/itkwasm_htj2k.svg)](https://pypi.org/project/itkwasm_htj2k/)

## Installation

::::{tab-set}

:::{tab-item} System
```shell
pip install itkwasm-htj2k
```
:::

:::{tab-item} Browser
In Pyodide, e.g. the [Pyodide REPL](https://pyodide.org/en/stable/console.html) or [JupyterLite](https://jupyterlite.readthedocs.io/en/latest/try/lab),

```python
import micropip
await micropip.install('itkwasm-htj2k')
:::

::::

```{toctree}
:hidden:
:maxdepth: 3
:caption: 📖 Reference

apidocs/index.rst
itkwasm docs <https://itkwasm.readthedocs.io/>
```